@@ -78,6 +78,14 @@ def create_ducktape_parser():
                         help="The size of a random test sample to run")
     parser.add_argument("--fail-bad-cluster-utilization", action="store_true",
                         help="Fail a test if the cluster node utilization does not match the cluster node usage.")
+    parser.add_argument("--test-runner-timeout", action="store", type=int, default=1800000,
+                        help="Amount of time in milliseconds between test communicating between the test runner"
+                             " before a timeout error occurs. Default is 30 minutes")
+    parser.add_argument("--ssh-checker-function", action="store", type=str, nargs="+",
+                        help="Python module path(s) to a function that takes an exception and a remote account"
+                        " that will be called when an ssh error occurs, this can give some "
+                        "validation or better logging when an ssh error occurs. Specify any "
+                        "number of module paths after this flag to be called.")
     return parser
 
 
